@@ -50,7 +50,6 @@
 package com.openexchange.http.grizzly.osgi;
 
 import java.util.concurrent.ExecutorService;
-import org.apache.commons.logging.Log;
 import org.glassfish.grizzly.comet.CometAddOn;
 import org.glassfish.grizzly.http.ajp.AjpAddOn;
 import org.glassfish.grizzly.http.server.NetworkListener;
@@ -63,6 +62,7 @@ import org.osgi.framework.FrameworkEvent;
 import org.osgi.framework.FrameworkListener;
 import org.osgi.service.http.HttpService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
 import com.openexchange.http.grizzly.GrizzlyConfig;
 import com.openexchange.http.grizzly.GrizzlyExceptionCode;
@@ -91,13 +91,12 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
     @Override
     protected void startBundle() throws OXException {
-        final org.apache.commons.logging.Log log = com.openexchange.log.Log.loggerFor(GrizzlyActivator.class);
+        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(GrizzlyActivator.class);
         try {
             Services.setServiceLookup(this);
+            trackService(DispatcherPrefixService.class);
 
-            if (log.isInfoEnabled()) {
-                log.info("Starting Grizzly server.");
-            }
+            log.info("Starting Grizzly server.");
             context.addFrameworkListener(new FrameworkListener() {
 
                 @Override
@@ -113,7 +112,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
                 }
             });
 
-            GrizzlyConfig grizzlyConfig = GrizzlyConfig.getInstance();
+            final GrizzlyConfig grizzlyConfig = GrizzlyConfig.getInstance();
             grizzlyConfig.start();
 
             /*
@@ -124,6 +123,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
             ServerConfiguration serverConfiguration = grizzly.getServerConfiguration();
             serverConfiguration.setMaxRequestParameters(grizzlyConfig.getMaxRequestParameters());
+            serverConfiguration.setAllowPayloadForUndefinedHttpMethods(true);
 
             final NetworkListener networkListener = new NetworkListener("http-listener", grizzlyConfig.getHttpHost(), grizzlyConfig.getHttpPort());
 
@@ -136,9 +136,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
             if (grizzlyConfig.isAJPEnabled()) {
                 networkListener.registerAddOn(new AjpAddOn());
-                if (log.isInfoEnabled()) {
-                    log.info("Enabled AJP for Grizzly server.");
-                }
+                log.info("Enabled AJP for Grizzly server.");
             }
 
             // Set the transport
@@ -162,40 +160,30 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
             if (grizzlyConfig.isJMXEnabled()) {
                 grizzly.getServerConfiguration().setJmxEnabled(true);
-                if (log.isInfoEnabled()) {
-                    log.info("Enabled JMX for Grizzly server.");
-                }
+                log.info("Enabled JMX for Grizzly server.");
             }
 
             if (grizzlyConfig.isWebsocketsEnabled()) {
                 networkListener.registerAddOn(new WebSocketAddOn());
-                if (log.isInfoEnabled()) {
-                    log.info("Enabled WebSockets for Grizzly server.");
-                }
+                log.info("Enabled WebSockets for Grizzly server.");
             }
 
             if (grizzlyConfig.isCometEnabled()) {
                 networkListener.registerAddOn(new CometAddOn());
                 registerService(CometContextService.class, new CometContextServiceImpl());
-                if (log.isInfoEnabled()) {
-                    log.info("Enabled Comet for Grizzly server.");
-                }
+                log.info("Enabled Comet for Grizzly server.");
             }
 
             grizzly.addListener(networkListener);
             grizzly.start();
-            if (log.isInfoEnabled()) {
-                log.info(String.format("Registered Grizzly HttpNetworkListener on host: %s and port: %s", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getHttpPort())));
-            }
+            log.info("Registered Grizzly HttpNetworkListener on host: {} and port: {}", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getHttpPort()));
 
             /*
              * Servicefactory that creates instances of the HttpService interface that grizzly implements. Each distinct bundle that uses
              * getService() will get its own instance of HttpServiceImpl
              */
             registerService(HttpService.class.getName(), new HttpServiceFactory(grizzly, context.getBundle()));
-            if (log.isInfoEnabled()) {
-                log.info("Registered OSGi HttpService for Grizzly server.");
-            }
+            log.info("Registered OSGi HttpService for Grizzly server.");
 
         } catch (final Exception e) {
             throw GrizzlyExceptionCode.GRIZZLY_SERVER_NOT_STARTED.create(e, new Object[] {});
@@ -204,18 +192,13 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
     @Override
     protected void stopBundle() throws Exception {
-        final Log log = com.openexchange.log.Log.loggerFor(GrizzlyActivator.class);
+        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(GrizzlyActivator.class);
+        log.info("Unregistering services.");
+        super.stopBundle();
 
         Services.setServiceLookup(null);
 
-        if (log.isInfoEnabled()) {
-            log.info("Unregistering services.");
-        }
-        cleanUp();
-
-        if (log.isInfoEnabled()) {
-            log.info("Stopping Grizzly.");
-        }
+        log.info("Stopping Grizzly.");
         final OXHttpServer grizzly = this.grizzly;
         if (null != grizzly) {
             grizzly.stop();
