@@ -314,11 +314,11 @@ public class OXHttpServer extends HttpServer {
         for (final NetworkListener listener : listeners.values()) {
             configureListener(listener);
         }
-        
+
         if (serverConfig.isJmxEnabled()) {
             enableJMX();
         }
-        
+
         for (final NetworkListener listener : listeners.values()) {
             try {
                 listener.start();
@@ -657,6 +657,9 @@ public class OXHttpServer extends HttpServer {
                 builder.add(new ResourceAllocationFilter());
             }
 
+            httpServerFilter.setAllowPayloadForUndefinedHttpMethods(
+                serverConfig.isAllowPayloadForUndefinedHttpMethods());
+
             httpServerFilter.getMonitoringConfig().addProbes(
                     serverConfig.getMonitoringConfig().getHttpConfig().getProbes());
             builder.add(httpServerFilter);
@@ -686,7 +689,7 @@ public class OXHttpServer extends HttpServer {
             config.setMaxFormPostSize(listener.getMaxFormPostSize());
             config.setMaxBufferedPostSize(listener.getMaxBufferedPostSize());
             config.setDefaultQueryEncoding(Charsets.lookupCharset(GrizzlyConfig.getInstance().getDefaultEncoding()));
-            
+
 
             webServerFilter.setHttpHandler(httpHandlerChain);
 
