@@ -101,10 +101,13 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.glassfish.grizzly.Buffer;
 import org.glassfish.grizzly.Connection;
+import org.glassfish.grizzly.ConnectionProbe;
 import org.glassfish.grizzly.Grizzly;
+import org.glassfish.grizzly.IOEvent;
 import org.glassfish.grizzly.ReadHandler;
 import org.glassfish.grizzly.attributes.Attribute;
 import org.glassfish.grizzly.filterchain.FilterChainContext;
+import org.glassfish.grizzly.filterchain.FilterChainContext.CompletionListener;
 import org.glassfish.grizzly.filterchain.NextAction;
 import org.glassfish.grizzly.http.HttpContent;
 import org.glassfish.grizzly.http.HttpPacket;
@@ -122,6 +125,7 @@ import org.glassfish.grizzly.monitoring.jmx.JmxObject;
 import org.glassfish.grizzly.utils.DelayedExecutor;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.http.grizzly.osgi.Services;
+import com.openexchange.http.grizzly.util.RequestTools;
 import com.openexchange.java.Charsets;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
@@ -179,17 +183,68 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
         }
     }
 
-    private static final class WatchInfo {
+    private static final class WatchInfo implements CompletionListener, ConnectionProbe {
 
         final ScheduledTimerTask timerTask;
         final Response handlerResponse;
+        private final AtomicInteger pingCount;
+        private final Object sync;
+        private long lastReadTime = -1;
 
-        WatchInfo(ScheduledTimerTask timerTask, Response handlerResponse) {
+        WatchInfo(ScheduledTimerTask timerTask, Response handlerResponse, AtomicInteger pingCount, Object sync) {
             super();
             this.timerTask = timerTask;
             this.handlerResponse = handlerResponse;
+            this.pingCount = pingCount;
+            this.sync = sync;
         }
 
+        @Override
+        public void onComplete(final FilterChainContext context) {
+            stopPing();
+        }
+
+        public void stopPing() {
+            synchronized (sync) {
+                pingCount.set(-1);
+            }
+        }
+
+        @Override
+        public void onBindEvent(Connection connection) {}
+
+        @Override
+        public void onAcceptEvent(Connection serverConnection, Connection clientConnection) {}
+
+        @Override
+        public void onConnectEvent(Connection connection) {}
+
+        @Override
+        public void onReadEvent(Connection connection, Buffer data, int size) {
+            lastReadTime = System.currentTimeMillis();
+        }
+
+        @Override
+        public void onWriteEvent(Connection connection, Buffer data, long size) {
+            // Sending a ping will touch the lastWriteTime
+            //lastWriteTime = System.currentTimeMillis();
+        }
+
+        @Override
+        public void onErrorEvent(Connection connection, Throwable error) {}
+
+        @Override
+        public void onCloseEvent(Connection connection) {}
+
+        @Override
+        public void onIOEventReadyEvent(Connection connection, IOEvent ioEvent) {}
+
+        @Override
+        public void onIOEventEnableEvent(Connection connection, IOEvent ioEvent) {}
+
+        @Override
+        public void onIOEventDisableEvent(Connection connection, IOEvent ioEvent) {}
+
     }
 
     private static final Logger LOGGER = Grizzly.logger(OXHttpServerFilter.class);
@@ -284,7 +339,9 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
                         final HttpHandler httpHandlerLocal = httpHandler;
                         if (httpHandlerLocal != null) {
                             // Initiate ping
-                            pingInitiated = initiatePing(handlerResponse, ctx);
+                            if (allowsPing(handlerRequest) && !isLongRunning(handlerRequest)) {
+                                pingInitiated = initiatePing(handlerResponse, ctx);
+                            }
                             // Handle HTTP message
                             httpHandlerLocal.doHandle(handlerRequest, handlerResponse);
                         }
@@ -312,7 +369,10 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
                     if (pingInitiated) {
                         final WatchInfo watchInfo = pingMap.remove(ctx);
                         if (null != watchInfo) {
+                            watchInfo.stopPing();
                             watchInfo.timerTask.cancel(false);
+                            ctx.removeCompletionListener(watchInfo);
+                            connection.getMonitoringConfig().removeProbes(watchInfo);
                             // Canceled timer task gets purged by CustomThreadPoolExecutorTimerService.PurgeRunnable
                         }
                     }
@@ -355,6 +415,16 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
         return ctx.getStopAction();
     }
 
+    private boolean isLongRunning(final Request request) {
+        return RequestTools.isUsmJsonOrEasRequest(request);
+    }
+
+    private static final String USM_USER_AGENT = "Open-Xchange USM HTTP Client";
+
+    private boolean allowsPing(Request request) {
+        return !USM_USER_AGENT.equals(request.getHeader("User-Agent"));
+    }
+
     private boolean initiatePing(final Response handlerResponse, final FilterChainContext ctx) {
         final Ping ping = this.ping;
         if (ping != Ping.NONE) {
@@ -362,6 +432,7 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
             if (null != timerService) {
                 final ConcurrentMap<FilterChainContext, WatchInfo> cm = pingMap;
                 final Logger logger = LOGGER;
+                final boolean debugEnabled = logger.isLoggable(Level.FINE);
                 final byte[] crlfBytes = CRLF;
 
                 final int maxPingCount = this.maxPingCount;
@@ -372,54 +443,80 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
                 final Runnable r = new Runnable() {
 
                     @Override
-                    public void run() {
+                    public synchronized void run() {
                         try {
                             final WatchInfo watchInfo = cm.get(ctx);
                             boolean pingIssued = false;
                             if (null != watchInfo && (watchInfo.handlerResponse instanceof OXResponse)) {
-                                final StampingNIOOutputStreamImpl stamped = (StampingNIOOutputStreamImpl) ((OXResponse) watchInfo.handlerResponse).createOutputStream();
-                                if (!stamped.closed) {
-                                    final long lastAccessed = stamped.lastAccessed;
-                                    if (lastAccessed > 0 && (System.currentTimeMillis() - lastAccessed) >= pingDelay) {
-                                        // Check whether to issue a ping
-                                        if (pingCount.decrementAndGet() < 0) {
-                                            // Not allowed to issue a further ping
-                                            final ScheduledTimerTask timerTask = ref.get();
-                                            if (null != timerTask) {
-                                                timerTask.cancel(false);
-                                            }
-                                            return;
-                                        }
 
-                                        // Issue a ping
-                                        final MemoryManager memoryManager = ctx.getMemoryManager();
-                                        if (Ping.PROCESSING == ping) {
-                                            final Buffer encodedBuffer = memoryManager.allocate(128);
-                                            put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 102 Processing"));
-                                            put(memoryManager, encodedBuffer, crlfBytes);
-                                            put(memoryManager, encodedBuffer, crlfBytes);
-                                            encodedBuffer.trim();
-                                            encodedBuffer.allowBufferDispose(true);
-                                            ctx.write(encodedBuffer, true);
-                                        } else if (Ping.CONTINUE == ping) {
-                                            final Buffer encodedBuffer = memoryManager.allocate(128);
-                                            put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 100 Continue"));
-                                            put(memoryManager, encodedBuffer, crlfBytes);
-                                            put(memoryManager, encodedBuffer, crlfBytes);
-                                            encodedBuffer.trim();
-                                            encodedBuffer.allowBufferDispose(true);
-                                            ctx.write(encodedBuffer, true);
-                                        } else {
-                                            final Buffer buffer = memoryManager.allocate(128);
-                                            put(memoryManager, buffer, Charsets.toAsciiBytes(" "));
-                                            buffer.trim();
-                                            buffer.allowBufferDispose(true);
-                                            final OutputBuffer outputBuffer = handlerResponse.getOutputBuffer();
-                                            outputBuffer.writeBuffer(buffer);
-                                            outputBuffer.flush();
+                                //We are still reading from the client?
+                                long readDiffMillis = System.currentTimeMillis() - watchInfo.lastReadTime;
+                                if(readDiffMillis < pingDelay) {
+                                    return;
+                                }
+
+                                final StampingNIOOutputStreamImpl stamped = (StampingNIOOutputStreamImpl) ((OXResponse) watchInfo.handlerResponse).createOutputStream();
+
+                                // Issue a ping as long as stream not closed AND nothing has been written to upstream
+                                if (stamped.closed || !stamped.doPing) {
+                                    if (debugEnabled) {
+                                        final Request request = ((OXResponse) watchInfo.handlerResponse).getRequest();
+                                        if (null != request) {
+                                            final String action = request.getParameter("action");
+                                            logger.fine("OXHttpServerFilter: Aborted 102 Processing interim responses for " + request.getRequestURI() + (null == action ? "" : "?action=" + action));
                                         }
-                                        pingIssued = true;
                                     }
+                                    // Not allowed/possible to issue a further ping as data was already transferred
+                                    final ScheduledTimerTask timerTask = ref.get();
+                                    if (null != timerTask) {
+                                        timerTask.cancel(false);
+                                    }
+                                    return;
+                                }
+
+                                // Check whether to issue a further ping
+                                if (pingCount.decrementAndGet() < 0) {
+                                    // Not allowed to issue a further ping
+                                    final ScheduledTimerTask timerTask = ref.get();
+                                    if (null != timerTask) {
+                                        timerTask.cancel(false);
+                                    }
+                                    return;
+                                }
+
+                                // Issue a ping
+                                final MemoryManager memoryManager = ctx.getMemoryManager();
+                                if (Ping.PROCESSING == ping) {
+                                    final Buffer encodedBuffer = memoryManager.allocate(128);
+                                    put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 102 Processing"));
+                                    put(memoryManager, encodedBuffer, crlfBytes);
+                                    put(memoryManager, encodedBuffer, crlfBytes);
+                                    encodedBuffer.trim();
+                                    encodedBuffer.allowBufferDispose(true);
+                                    ctx.write(encodedBuffer, true);
+                                    if (debugEnabled) {
+                                        final Request request = ((OXResponse) watchInfo.handlerResponse).getRequest();
+                                        if (null != request) {
+                                            final String action = request.getParameter("action");
+                                            logger.fine("OXHttpServerFilter: Issued a 102 Processing interim response for " + request.getRequestURI() + (null == action ? "" : "?action=" + action));
+                                        }
+                                    }
+                                } else if (Ping.CONTINUE == ping) {
+                                    final Buffer encodedBuffer = memoryManager.allocate(128);
+                                    put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 100 Continue"));
+                                    put(memoryManager, encodedBuffer, crlfBytes);
+                                    put(memoryManager, encodedBuffer, crlfBytes);
+                                    encodedBuffer.trim();
+                                    encodedBuffer.allowBufferDispose(true);
+                                    ctx.write(encodedBuffer, true);
+                                } else {
+                                    final Buffer buffer = memoryManager.allocate(128);
+                                    put(memoryManager, buffer, Charsets.toAsciiBytes(" "));
+                                    buffer.trim();
+                                    buffer.allowBufferDispose(true);
+                                    final OutputBuffer outputBuffer = handlerResponse.getOutputBuffer();
+                                    outputBuffer.writeBuffer(buffer);
+                                    outputBuffer.flush();
                                 }
                                 pingIssued = true;
                             }
@@ -434,7 +531,10 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
 
                 final ScheduledTimerTask timerTask = timerService.scheduleWithFixedDelay(r, pingDelay, pingDelay);
                 ref.set(timerTask);
-                cm.put(ctx, new WatchInfo(timerTask, handlerResponse));
+                final WatchInfo watchInfo = new WatchInfo(timerTask, handlerResponse, pingCount, r);
+                cm.put(ctx, watchInfo);
+                ctx.getConnection().getMonitoringConfig().addProbes(watchInfo);
+                ctx.addCompletionListener(watchInfo);
             }
         };
 
