@@ -52,14 +52,12 @@ package org.glassfish.grizzly.http.server;
 import static com.openexchange.tools.servlet.http.Cookies.extractDomainValue;
 import static com.openexchange.tools.servlet.http.Cookies.getDomainValue;
 import java.nio.charset.Charset;
-import org.apache.commons.logging.Log;
 import org.glassfish.grizzly.ThreadCache;
 import org.glassfish.grizzly.http.Cookie;
 import org.glassfish.grizzly.http.server.util.Globals;
 import org.glassfish.grizzly.utils.Charsets;
 import com.openexchange.http.grizzly.GrizzlyConfig;
 import com.openexchange.log.LogProperties;
-import com.openexchange.log.Props;
 import com.openexchange.tools.servlet.http.Cookies;
 
 /**
@@ -69,7 +67,7 @@ import com.openexchange.tools.servlet.http.Cookies;
  */
 public class OXRequest extends Request {
 
-    private static Log LOG = com.openexchange.log.Log.loggerFor(OXRequest.class);
+    private static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(OXRequest.class);
 
     private static final GrizzlyConfig grizzlyConfig = GrizzlyConfig.getInstance();
 
@@ -88,7 +86,8 @@ public class OXRequest extends Request {
 
     private String XForwardProto = null;
     private int XForwardPort = 0;
-    private final boolean isConsiderXForwards = grizzlyConfig.isConsiderXForwards();
+    private boolean isConsiderXForwards = grizzlyConfig.isConsiderXForwards();
+    private boolean isForcedSecurity = false;
 
     protected OXRequest(Response response) {
         super(response);
@@ -98,6 +97,8 @@ public class OXRequest extends Request {
     protected void recycle() {
         XForwardProto = null;
         XForwardPort = 0;
+        isConsiderXForwards = grizzlyConfig.isConsiderXForwards();
+        isForcedSecurity = false;
         super.recycle();
     }
 
@@ -194,9 +195,7 @@ public class OXRequest extends Request {
         } else {
             String sessionId = createSessionID();
             registerNewSession(sessionId);
-            if (LOG.isDebugEnabled()) {
-                LOG.debug("Set new JSessionId Cookie: " + sessionId);
-            }
+            LOG.debug("Set new JSessionId Cookie: {}", sessionId);
         }
         return session;
     }
@@ -220,10 +219,7 @@ public class OXRequest extends Request {
         session.setSessionTimeout(grizzlyConfig.getCookieMaxInactivityInterval() * 1000);
         sessions.put(sessionId, session);
         response.addCookie(createSessionCookie(sessionId));
-        if (LogProperties.isEnabled()) {
-            Props logProperties = LogProperties.getLogProperties();
-            logProperties.put(LogProperties.Name.GRIZZLY_HTTP_SESSION, sessionId);
-        }
+        LogProperties.put(LogProperties.Name.GRIZZLY_HTTP_SESSION, sessionId);
     }
 
     /**
@@ -232,9 +228,7 @@ public class OXRequest extends Request {
      * @param invalidSessionId The invalid sessionId requested by the browser/cookie
      */
     private void removeInvalidSessionCookie(String invalidSessionId) {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Removing invalid JSessionId Cookie: " + invalidSessionId);
-        }
+        LOG.debug("Removing invalid JSessionId Cookie: {}", invalidSessionId);
         for (Cookie cookie : cookies) {
             if (cookie.getName().startsWith(Globals.SESSION_COOKIE_NAME)) {
                 if (cookie.getValue().equals(invalidSessionId)) {
@@ -379,4 +373,25 @@ public class OXRequest extends Request {
         return charset;
     }
 
+    /*
+     * We can't look up certificate or ssl attributes as long as the http balancer terminates ssl in our setup. Yet we have to set the
+     * Request to secure for e.g. using the correct schema(http/https) when generating urls and the request reached the balancer via https.
+     * To circumvent problems arising when clients ask for e.g. certificate or ssl attributes on an unsecure Request that is marked as
+     * secure we'll return null.
+     */
+    @Override
+    public Object getAttribute(String name) {
+        if( Globals.SSL_CERTIFICATE_ATTR.equals(name) || isSSLAttribute(name)) {
+            //Did we force a secure request although the balancer terminated https
+            Object attribute = getAttribute("com.openexchange.http.isForcedSecurity");
+            if(attribute != null) {
+                isForcedSecurity = (Boolean)attribute;
+            }
+            if(isForcedSecurity) {
+                return null;
+            }
+        }
+        return super.getAttribute(name);
+    }
+
 }
