@@ -58,13 +58,11 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.http.requestwatcher.osgi.Services;
 import com.openexchange.http.requestwatcher.osgi.services.RequestRegistryEntry;
 import com.openexchange.http.requestwatcher.osgi.services.RequestWatcherService;
 import com.openexchange.log.LogProperties;
-import com.openexchange.log.Props;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.sessiond.SessiondServiceExtended;
 import com.openexchange.timer.ScheduledTimerTask;
@@ -78,7 +76,7 @@ import com.openexchange.timer.TimerService;
 public class RequestWatcherServiceImpl implements RequestWatcherService {
 
     /** The logger. */
-    protected static final Log LOG = com.openexchange.log.Log.loggerFor(RequestWatcherServiceImpl.class);
+    protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(RequestWatcherServiceImpl.class);
 
     /** The request number */
     private static final AtomicLong NUMBER = new AtomicLong();
@@ -112,36 +110,40 @@ public class RequestWatcherServiceImpl implements RequestWatcherService {
                  */
                 @Override
                 public void run() {
-                    final boolean debugEnabled = LOG.isDebugEnabled();
-                    final Iterator<RequestRegistryEntry> descendingEntryIterator = requestRegistry.descendingIterator();
-                    final StringBuilder sb = new StringBuilder(256);
-                    boolean stillOldRequestsLeft = true;
-                    while (stillOldRequestsLeft && descendingEntryIterator.hasNext()) {
-                        if (debugEnabled) {
-                            sb.setLength(0);
-                            for (final RequestRegistryEntry entry : requestRegistry) {
-                                sb.append(lineSeparator).append("RegisteredThreads:").append(lineSeparator).append("    age: ").append(entry.getAge()).append(" ms").append(
-                                    ", thread: ").append(entry.getThreadInfo());
+                    try {
+                        final boolean debugEnabled = LOG.isDebugEnabled();
+                        final Iterator<RequestRegistryEntry> descendingEntryIterator = requestRegistry.descendingIterator();
+                        final StringBuilder sb = new StringBuilder(256);
+                        boolean stillOldRequestsLeft = true;
+                        while (stillOldRequestsLeft && descendingEntryIterator.hasNext()) {
+                            if (debugEnabled) {
+                                sb.setLength(0);
+                                for (final RequestRegistryEntry entry : requestRegistry) {
+                                    sb.append(lineSeparator).append("RegisteredThreads:").append(lineSeparator).append("    age: ").append(entry.getAge()).append(" ms").append(
+                                        ", thread: ").append(entry.getThreadInfo());
+                                }
+                                final String entries = sb.toString();
+                                if (!entries.isEmpty()) {
+                                    LOG.debug(sb.toString());
+                                }
                             }
-                            final String entries = sb.toString();
-                            if (!entries.isEmpty()) {
-                                LOG.debug(sb);
+                            final RequestRegistryEntry requestRegistryEntry = descendingEntryIterator.next();
+                            if (requestRegistryEntry.getAge() > requestMaxAge) {
+                                sb.setLength(0);
+                                logRequestRegistryEntry(requestRegistryEntry, sb);
+                                // Don't remove
+                                // requestRegistry.remove(requestRegistryEntry);
+                            } else {
+                                stillOldRequestsLeft = false;
                             }
                         }
-                        final RequestRegistryEntry requestRegistryEntry = descendingEntryIterator.next();
-                        if (requestRegistryEntry.getAge() > requestMaxAge) {
-                            sb.setLength(0);
-                            logRequestRegistryEntry(requestRegistryEntry, sb);
-                            // Don't remove
-                            // requestRegistry.remove(requestRegistryEntry);
-                        } else {
-                            stillOldRequestsLeft = false;
-                        }
+                    } catch (final Exception e) {
+                        LOG.error("Request watcher run failed", e);
                     }
                 }
 
                 private void logRequestRegistryEntry(final RequestRegistryEntry entry, final StringBuilder logBuilder) {
-                    final Throwable trace = new Throwable();
+                    final Throwable trace = new FastThrowable();
                     {
                         final StackTraceElement[] stackTrace = entry.getStackTrace();
                         if (dontLog(stackTrace)) {
@@ -153,40 +155,28 @@ public class RequestWatcherServiceImpl implements RequestWatcherService {
 
                     // If we have additional log properties from the ThreadLocal add it to the logBuilder
                     {
-                        final Props logProperties = LogProperties.optLogProperties(entry.getThread());
-                        if (logProperties != null) {
-                            Map<String, Object> propertyMap = logProperties.asMap();
-                            // Sort the properties for readability
-                            Map<String, String> sorted = new TreeMap<String, String>();
-                            for (Entry<String, Object> propertyEntry : propertyMap.entrySet()) {
-                                String propertyName = propertyEntry.getKey();
-                                Object value = propertyEntry.getValue();
-                                if (null != value) {
-                                    if (LogProperties.Name.SESSION_SESSION_ID.getName().equals(propertyName) && !isValidSession(value.toString())) {
-                                        // Non-existent or elapsed session
-                                        entry.getThread().interrupt();
-                                        requestRegistry.remove(entry);
-                                        return;
-                                    }
-                                    sorted.put(propertyName, value.toString());
+                        // Sort the properties for readability
+                        Map<String, String> sorted = new TreeMap<String, String>();
+                        for (Entry<String, String> propertyEntry : entry.getPropertyMap().entrySet()) {
+                            String propertyName = propertyEntry.getKey();
+                            String value = propertyEntry.getValue();
+                            if (null != value) {
+                                if (LogProperties.Name.SESSION_SESSION_ID.getName().equals(propertyName) && !isValidSession(value.toString())) {
+                                    // Non-existent or elapsed session
+                                    entry.getThread().interrupt();
+                                    requestRegistry.remove(entry);
+                                    return;
                                 }
-                            }
-                            logBuilder.append("with properties:").append(lineSeparator);
-                            // And add them to the logBuilder
-                            for (Map.Entry<String, String> propertyEntry : sorted.entrySet()) {
-                                logBuilder.append(propertyEntry.getKey()).append('=').append(propertyEntry.getValue()).append(lineSeparator);
+                                sorted.put(propertyName, value);
                             }
                         }
+                        logBuilder.append("with properties:").append(lineSeparator);
+                        // And add them to the logBuilder
+                        for (Map.Entry<String, String> propertyEntry : sorted.entrySet()) {
+                            logBuilder.append(propertyEntry.getKey()).append('=').append(propertyEntry.getValue()).append(lineSeparator);
+                        }
                     }
 
-                    // Make sure not to log any client specific parameters as security consideration
-                    // String requestParameters = entry.getRequestParameters();
-                    // if(!requestParameters.isEmpty()) {
-                    // logBuilder
-                    // .append("with parameters:").append(lineSeparator)
-                    // .append(requestParameters).append(lineSeparator);
-                    // }
-
                     LOG.info(logBuilder.append("with age: ").append(entry.getAge()).append("ms exceeds max. age of: ").append(requestMaxAge).append("ms.").toString(), trace);
                 }
 
@@ -216,8 +206,8 @@ public class RequestWatcherServiceImpl implements RequestWatcherService {
     }
 
     @Override
-    public RequestRegistryEntry registerRequest(final HttpServletRequest request, final HttpServletResponse response, final Thread thread) {
-        final RequestRegistryEntry registryEntry = new RequestRegistryEntry(NUMBER.incrementAndGet(), request, response, thread);
+    public RequestRegistryEntry registerRequest(final HttpServletRequest request, final HttpServletResponse response, final Thread thread, final Map<String, String> propertyMap) {
+        final RequestRegistryEntry registryEntry = new RequestRegistryEntry(NUMBER.incrementAndGet(), request, response, thread, propertyMap);
         requestRegistry.add(registryEntry);
         return registryEntry;
     }
@@ -236,4 +226,18 @@ public class RequestWatcherServiceImpl implements RequestWatcherService {
         return true;
     }
 
+    // ----------------------------------------------------------------------------- //
+
+    static final class FastThrowable extends Throwable {
+
+        FastThrowable() {
+            super("tracked request");
+        }
+
+        @Override
+        public synchronized Throwable fillInStackTrace() {
+            return this;
+        }
+    }
+
 }
